Crate codama_plugin_core
codama_
plugin_
core
0.10.0
All Items
Crate Items
Structs
Traits
Functions
Type Aliases
Crate
codama_
plugin_
core
Structs

Composite
Directive
Resolver
A
DirectiveResolver
built from all installed plugins. Iterates over plugins to find one that can resolve the given directive.
Default
Plugin
Resolve
Directives
Visitor
A visitor that resolves all
Resolvable::Unresolved
entries in the korok tree by delegating to the
DirectiveResolver
.
Traits

Directive
Resolver
Trait that allows plugins to resolve directives from other plugins. The framework builds a
DirectiveResolver
from all installed plugins and passes it to
resolve_type_directive
/
resolve_value_directive
.
Korok
Plugin
Functions

resolve_
plugins
Combine all plugins into a single function that runs them in sequence.
Type Aliases

Resolve
Plugins
Result