ResolveDirectivesVisitor

Struct ResolveDirectivesVisitor 

pub struct ResolveDirectivesVisitor<'a> { /* private fields */ }
A visitor that resolves all Resolvable::Unresolved entries in the korok tree by delegating to the DirectiveResolver.

This visitor runs automatically as the first step in resolve_plugins(), before any lifecycle hooks fire.

Implementations

Source

impl<'a> ResolveDirectivesVisitor<'a>

pub fn new(resolver: &'a dyn DirectiveResolver) -> Self